Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(416)

Unified Diff: Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h

Issue 16020003: Blink-side Device Motion API testing. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: fixed window-property layout test Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h
diff --git a/Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h b/Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h
index 5e21add47749f946abbd1288a8098a9d9180892f..ace84f2af148b6cbe946abf228bf0325940b051e 100644
--- a/Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h
+++ b/Tools/DumpRenderTree/chromium/TestRunner/src/TestRunner.h
@@ -270,7 +270,8 @@ private:
void enableAutoResizeMode(const CppArgumentList&, CppVariant*);
void disableAutoResizeMode(const CppArgumentList&, CppVariant*);
- // DeviceOrientation related functions
+ // Device Motion / Device Orientation related functions
+ void setMockDeviceMotion(const CppArgumentList&, CppVariant*);
void setMockDeviceOrientation(const CppArgumentList&, CppVariant*);
void didAcquirePointerLock(const CppArgumentList&, CppVariant*);

Powered by Google App Engine
This is Rietveld 408576698